<?php
/**
 * Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */

// Add Gallery section
$wp_customize->add_section( 'musicsong_pro_gallery_section', array(
	'title'             => esc_html__( 'Gallery','musicsong-pro' ),
	'description'       => esc_html__( 'Gallery Section options.', 'musicsong-pro' ),
	'panel'             => 'musicsong_pro_front_page_panel',
) );

// Gallery content enable control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[gallery_section_enable]', array(
	'default'			=> 	$options['gallery_section_enable'],
	'sanitize_callback' => 'musicsong_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Musicsong_Pro_Switch_Control( $wp_customize, 'musicsong_pro_theme_options[gallery_section_enable]', array(
	'label'             => esc_html__( 'Gallery Section Enable', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_gallery_section',
	'on_off_label' 		=> musicsong_pro_switch_options(),
) ) );

// gallery title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[gallery_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[gallery_title]', array(
	'label'           	=> esc_html__( 'Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_gallery_section',
	'active_callback' 	=> 'musicsong_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[gallery_title]', array(
		'selector'            => '#featured-gallery h2.section-title',
		'settings'            => 'musicsong_pro_theme_options[gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_gallery_title_partial',
    ) );
}

// gallery subtitle setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[gallery_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[gallery_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_gallery_section',
	'active_callback' 	=> 'musicsong_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[gallery_subtitle]', array(
		'selector'            => '#featured-gallery p.section-subtitle',
		'settings'            => 'musicsong_pro_theme_options[gallery_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_gallery_subtitle_partial',
    ) );
}

// Gallery content type control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[gallery_content_type]', array(
	'default'          	=> $options['gallery_content_type'],
	'sanitize_callback' => 'musicsong_pro_sanitize_select',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[gallery_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_gallery_section',
	'type'				=> 'select',
	'active_callback' 	=> 'musicsong_pro_is_gallery_section_enable',
	'choices'			=> musicsong_pro_gallery_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[gallery_count]', array(
	'default'          	=> $options['gallery_count'],
	'sanitize_callback' => 'musicsong_pro_sanitize_number_range',
	'validate_callback' => 'musicsong_pro_validate_gallery_count',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[gallery_count]', array(
	'label'             => esc_html__( 'Number of Gallery', 'musicsong-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_gallery_section',
	'active_callback'   => 'musicsong_pro_is_gallery_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['gallery_count']; $i++ ) :

	// gallery posts drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_gallery_section',
		'choices'			=> musicsong_pro_page_choices(),
		'active_callback'	=> 'musicsong_pro_is_gallery_section_content_page_enable',
	) ) );

	// gallery posts drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_gallery_section',
		'choices'			=> musicsong_pro_post_choices(),
		'active_callback'	=> 'musicsong_pro_is_gallery_section_content_post_enable',
	) ) );

	// gallery posts drop down chooser control and setting
	$wp_customize->add_setting( 'musicsong_pro_theme_options[gallery_content_product_' . $i . ']', array(
		'sanitize_callback' => 'musicsong_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[gallery_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'musicsong-pro' ), $i ),
		'section'           => 'musicsong_pro_gallery_section',
		'choices'			=> musicsong_pro_product_choices(),
		'active_callback'	=> 'musicsong_pro_is_gallery_section_content_product_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'musicsong_pro_theme_options[gallery_content_category]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Taxonomies_Control( $wp_customize,'musicsong_pro_theme_options[gallery_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'musicsong-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_gallery_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'musicsong_pro_is_gallery_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'musicsong_pro_theme_options[gallery_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Taxonomies_Control( $wp_customize,'musicsong_pro_theme_options[gallery_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'musicsong-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_gallery_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'musicsong_pro_is_gallery_section_content_product_category_enable'
) ) );