<?php
/**
 * Promotion Section options
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */

// Add Promotion section
$wp_customize->add_section( 'musicsong_pro_promotion_section', array(
	'title'             => esc_html__( 'Promotion','musicsong-pro' ),
	'description'       => esc_html__( 'Promotion Section options.', 'musicsong-pro' ),
	'panel'             => 'musicsong_pro_front_page_panel',
) );

// Promotion content enable control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[promotion_section_enable]', array(
	'default'			=> 	$options['promotion_section_enable'],
	'sanitize_callback' => 'musicsong_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Musicsong_Pro_Switch_Control( $wp_customize, 'musicsong_pro_theme_options[promotion_section_enable]', array(
	'label'             => esc_html__( 'Promotion Section Enable', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_promotion_section',
	'on_off_label' 		=> musicsong_pro_switch_options(),
) ) );

// promotion subtitle setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[promotion_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['promotion_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[promotion_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_promotion_section',
	'active_callback' 	=> 'musicsong_pro_is_promotion_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[promotion_subtitle]', array(
		'selector'            => '#promotion-section .section-header p.section-subtitle',
		'settings'            => 'musicsong_pro_theme_options[promotion_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_promotion_subtitle_partial',
    ) );
}

// Promotion content type control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[promotion_content_type]', array(
	'default'          	=> $options['promotion_content_type'],
	'sanitize_callback' => 'musicsong_pro_sanitize_select',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[promotion_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_promotion_section',
	'type'				=> 'select',
	'active_callback' 	=> 'musicsong_pro_is_promotion_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'musicsong-pro' ),
		'post' 		=> esc_html__( 'Post', 'musicsong-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'musicsong-pro' ),
	),
) );

// promotion pages drop down chooser control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[promotion_content_page]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_page',
) );

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[promotion_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_promotion_section',
	'choices'			=> musicsong_pro_page_choices(),
	'active_callback'	=> 'musicsong_pro_is_promotion_section_content_page_enable',
) ) );

// promotion posts drop down chooser control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[promotion_content_post]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_page',
) );

$wp_customize->add_control( new Musicsong_Pro_Dropdown_Chooser( $wp_customize, 'musicsong_pro_theme_options[promotion_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_promotion_section',
	'choices'			=> musicsong_pro_post_choices(),
	'active_callback'	=> 'musicsong_pro_is_promotion_section_content_post_enable',
) ) );

// promotion title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[promotion_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['promotion_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[promotion_title]', array(
	'label'           	=> esc_html__( 'Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_promotion_section',
	'active_callback' 	=> 'musicsong_pro_is_promotion_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[promotion_title]', array(
		'selector'            => '#promotion-section .entry-container .section-header h2.section-title',
		'settings'            => 'musicsong_pro_theme_options[promotion_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_promotion_title_partial',
    ) );
}

// promotion description setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[promotion_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['promotion_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[promotion_description]', array(
	'label'           	=> esc_html__( 'Description', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_promotion_section',
	'active_callback' 	=> 'musicsong_pro_is_promotion_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[promotion_description]', array(
		'selector'            => '#promotion-section .entry-container .section-content p',
		'settings'            => 'musicsong_pro_theme_options[promotion_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_promotion_description_partial',
    ) );
}

// promotion image setting and control.
$wp_customize->add_setting( 'musicsong_pro_theme_options[promotion_image]', array(
	'sanitize_callback' => 'musicsong_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'musicsong_pro_theme_options[promotion_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'musicsong-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'musicsong-pro' ), 512, 520 ),
		'section'     		=> 'musicsong_pro_promotion_section',
		'active_callback'	=> 'musicsong_pro_is_promotion_section_content_custom_enable',
) ) );

// promotion btn title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[promotion_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['promotion_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[promotion_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_promotion_section',
	'active_callback' 	=> 'musicsong_pro_is_promotion_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[promotion_btn_title]', array(
		'selector'            => '#promotion-section .read-more a.btn-fill',
		'settings'            => 'musicsong_pro_theme_options[promotion_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_promotion_btn_title_partial',
    ) );
}

// promotion btn link setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[promotion_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[promotion_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_promotion_section',
	'active_callback' 	=> 'musicsong_pro_is_promotion_section_content_custom_enable',
	'type'				=> 'url',
) );

// promotion alt btn title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[promotion_alt_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['promotion_alt_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[promotion_alt_btn_title]', array(
	'label'           	=> esc_html__( 'Alt Button Label', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_promotion_section',
	'active_callback' 	=> 'musicsong_pro_is_promotion_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[promotion_alt_btn_title]', array(
		'selector'            => '#promotion-section .read-more a.alt-btn',
		'settings'            => 'musicsong_pro_theme_options[promotion_alt_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_promotion_alt_btn_title_partial',
    ) );
}

// promotion btn link setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[promotion_alt_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[promotion_alt_btn_link]', array(
	'label'           	=> esc_html__( 'Alt Button Link', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_promotion_section',
	'active_callback' 	=> 'musicsong_pro_is_promotion_section_enable',
	'type'				=> 'url',
) );