<?php
/**
 * Subscription Section options
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */

// Add Subscription section
$wp_customize->add_section( 'musicsong_pro_subscription_section', array(
	'title'             => esc_html__( 'Subscription','musicsong-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install Jetpack Plugin and activate subscription module.', 'musicsong-pro' ),
	'panel'             => 'musicsong_pro_front_page_panel',
) );

// Subscription content enable control and setting
$wp_customize->add_setting( 'musicsong_pro_theme_options[subscription_section_enable]', array(
	'default'			=> 	$options['subscription_section_enable'],
	'sanitize_callback' => 'musicsong_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Musicsong_Pro_Switch_Control( $wp_customize, 'musicsong_pro_theme_options[subscription_section_enable]', array(
	'label'             => esc_html__( 'Subscription Section Enable', 'musicsong-pro' ),
	'section'           => 'musicsong_pro_subscription_section',
	'on_off_label' 		=> musicsong_pro_switch_options(),
) ) );

// subscription title setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[subscription_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[subscription_title]', array(
	'label'           	=> esc_html__( 'Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_subscription_section',
	'active_callback' 	=> 'musicsong_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[subscription_title]', array(
		'selector'            => '#subscribe-us h2.section-title',
		'settings'            => 'musicsong_pro_theme_options[subscription_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_subscription_title_partial',
    ) );
}

// subscription subtitle setting and control
$wp_customize->add_setting( 'musicsong_pro_theme_options[subscription_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'musicsong_pro_theme_options[subscription_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'musicsong-pro' ),
	'section'        	=> 'musicsong_pro_subscription_section',
	'active_callback' 	=> 'musicsong_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'musicsong_pro_theme_options[subscription_subtitle]', array(
		'selector'            => '#subscribe-us p.section-subtitle',
		'settings'            => 'musicsong_pro_theme_options[subscription_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'musicsong_pro_subscription_subtitle_partial',
    ) );
}

