<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function musicsong_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'musicsong-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function musicsong_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'musicsong-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function musicsong_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'musicsong-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of events for post choices.
 * @return Array Array of post ids and name.
 */
function musicsong_pro_event_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'tp-event' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'musicsong-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of audio for post choices.
 * @return Array Array of post ids and name.
 */
function musicsong_pro_audio_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'attachment', 'post_mime_type' => 'audio' ) );
    $choices = array();
    $choices[0] = esc_html__( '--None--', 'musicsong-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'musicsong_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function musicsong_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'musicsong-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'musicsong-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'musicsong-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'musicsong-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'musicsong-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'musicsong-pro' ),
        );

        $output = apply_filters( 'musicsong_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'musicsong_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function musicsong_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'musicsong-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'musicsong-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'musicsong-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'musicsong-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'musicsong-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'musicsong-pro' ),
        );

        $output = apply_filters( 'musicsong_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'musicsong_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function musicsong_pro_site_layout() {
        $musicsong_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'musicsong_pro_site_layout', $musicsong_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'musicsong_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function musicsong_pro_selected_sidebar() {
        $musicsong_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'musicsong-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'musicsong-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'musicsong-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'musicsong-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'musicsong-pro' ),
        );

        $output = apply_filters( 'musicsong_pro_selected_sidebar', $musicsong_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'musicsong_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function musicsong_pro_global_sidebar_position() {
        $musicsong_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'musicsong_pro_global_sidebar_position', $musicsong_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'musicsong_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function musicsong_pro_sidebar_position() {
        $musicsong_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'musicsong_pro_sidebar_position', $musicsong_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'musicsong_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function musicsong_pro_pagination_options() {
        $musicsong_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'musicsong-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'musicsong-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'musicsong-pro' ),
        );

        $output = apply_filters( 'musicsong_pro_pagination_options', $musicsong_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'musicsong_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function musicsong_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'musicsong-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'musicsong-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'musicsong-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'musicsong-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'musicsong-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'musicsong-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'musicsong-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'musicsong-pro' ),
        );
        return apply_filters( 'musicsong_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'musicsong_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function musicsong_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'musicsong-pro' ),
            'off'       => esc_html__( 'Disable', 'musicsong-pro' )
        );
        return apply_filters( 'musicsong_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'musicsong_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function musicsong_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'musicsong-pro' ),
            'off'       => esc_html__( 'No', 'musicsong-pro' )
        );
        return apply_filters( 'musicsong_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'musicsong_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function musicsong_pro_sortable_sections() {
        $sections = array(
            'slider'    => esc_html__( 'Main Slider', 'musicsong-pro' ),
            'playlist'  => esc_html__( 'Playlist', 'musicsong-pro' ),
            'about'     => esc_html__( 'About Us', 'musicsong-pro' ),
            'hero_content' => esc_html__( 'Hero Content', 'musicsong-pro' ),
            'service'   => esc_html__( 'Services', 'musicsong-pro' ),
            'latest_release' => esc_html__( 'Latest Release', 'musicsong-pro' ),
            'cta'       => esc_html__( 'Call to Action', 'musicsong-pro' ),
            'event'     => esc_html__( 'Event', 'musicsong-pro' ),
            'gallery'   => esc_html__( 'Gallery', 'musicsong-pro' ),
            'testimonial' => esc_html__( 'Testimonial', 'musicsong-pro' ),
            'promotion' => esc_html__( 'Promotion', 'musicsong-pro' ),
            'product'   => esc_html__( 'Product', 'musicsong-pro' ),
            'artists'   => esc_html__( 'Artists', 'musicsong-pro' ),
            'blog'      => esc_html__( 'Blog', 'musicsong-pro' ),
        );
        return apply_filters( 'musicsong_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'musicsong_pro_slider_content_type' ) ) :
    /**
     * Slider Options
     * @return array site slider options
     */
    function musicsong_pro_slider_content_type() {
        $musicsong_pro_slider_content_type = array(
            'page'      => esc_html__( 'Page', 'musicsong-pro' ),
            'post'      => esc_html__( 'Post', 'musicsong-pro' ),
            'category'  => esc_html__( 'Category', 'musicsong-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $musicsong_pro_slider_content_type = array_merge( $musicsong_pro_slider_content_type, array(
                'product'   => esc_html__( 'Product', 'musicsong-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'musicsong-pro' ),
                ) );
        }

        $output = apply_filters( 'musicsong_pro_slider_content_type', $musicsong_pro_slider_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'musicsong_pro_latest_release_content_type' ) ) :
    /**
     * Latest Release Options
     * @return array site latest_release options
     */
    function musicsong_pro_latest_release_content_type() {
        $musicsong_pro_latest_release_content_type = array(
            'page'      => esc_html__( 'Page', 'musicsong-pro' ),
            'post'      => esc_html__( 'Post', 'musicsong-pro' ),
            'category'  => esc_html__( 'Category', 'musicsong-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $musicsong_pro_latest_release_content_type = array_merge( $musicsong_pro_latest_release_content_type, array(
                'product'   => esc_html__( 'Product', 'musicsong-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'musicsong-pro' ),
                ) );
        }

        $output = apply_filters( 'musicsong_pro_latest_release_content_type', $musicsong_pro_latest_release_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'musicsong_pro_event_content_type' ) ) :
    /**
     * Special Offer Options
     * @return array site event options
     */
    function musicsong_pro_event_content_type() {
        $musicsong_pro_event_content_type = array(
            'page'      => esc_html__( 'Page', 'musicsong-pro' ),
            'post'      => esc_html__( 'Post', 'musicsong-pro' ),
            'category'  => esc_html__( 'Category', 'musicsong-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $musicsong_pro_event_content_type = array_merge( $musicsong_pro_event_content_type, array(
                'event'   => esc_html__( 'Event', 'musicsong-pro' ),
                'event-category'   => esc_html__( 'Event Category', 'musicsong-pro' ),
                ) );
        }

        $output = apply_filters( 'musicsong_pro_event_content_type', $musicsong_pro_event_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'musicsong_pro_gallery_content_type' ) ) :
    /**
     * Gallery Options
     * @return array site gallery options
     */
    function musicsong_pro_gallery_content_type() {
        $musicsong_pro_gallery_content_type = array(
            'page'      => esc_html__( 'Page', 'musicsong-pro' ),
            'post'      => esc_html__( 'Post', 'musicsong-pro' ),
            'category'  => esc_html__( 'Category', 'musicsong-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $musicsong_pro_gallery_content_type = array_merge( $musicsong_pro_gallery_content_type, array(
                'product'   => esc_html__( 'Product', 'musicsong-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'musicsong-pro' ),
                ) );
        }

        $output = apply_filters( 'musicsong_pro_gallery_content_type', $musicsong_pro_gallery_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'musicsong_pro_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function musicsong_pro_product_content_type() {
        $musicsong_pro_product_content_type = array(
            'product'   => esc_html__( 'Product', 'musicsong-pro' ),
            'product-category'   => esc_html__( 'Product Category', 'musicsong-pro' ),
            'recent'    => esc_html__( 'Recent', 'musicsong-pro' ),
            'featured'  => esc_html__( 'Featured', 'musicsong-pro' ),
            'best-selling'  => esc_html__( 'Best Selling', 'musicsong-pro' ),
        );

        $output = apply_filters( 'musicsong_pro_product_content_type', $musicsong_pro_product_content_type );

        return $output;
    }
endif;