<?php
/**
 * Call to action section
 *
 * This is the template for the content of cta section
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */
if ( ! function_exists( 'musicsong_pro_add_cta_section' ) ) :
    /**
    * Add cta section
    *
    *@since Musicsong Pro 1.0.0
    */
    function musicsong_pro_add_cta_section() {
    	$options = musicsong_pro_get_theme_options();
        // Check if cta is enabled on frontpage
        $cta_enable = apply_filters( 'musicsong_pro_section_status', true, 'cta_section_enable' );

        if ( true !== $cta_enable ) {
            return false;
        }
        // Get cta section details
        $section_details = array();
        $section_details = apply_filters( 'musicsong_pro_filter_cta_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render cta section now.
        musicsong_pro_render_cta_section( $section_details );
    }
endif;

if ( ! function_exists( 'musicsong_pro_get_cta_section_details' ) ) :
    /**
    * cta section details.
    *
    * @since Musicsong Pro 1.0.0
    * @param array $input cta section details.
    */
    function musicsong_pro_get_cta_section_details( $input ) {
        $options = musicsong_pro_get_theme_options();

        // Content type.
        $cta_content_type  = $options['cta_content_type'];
        
        $content = array();
        switch ( $cta_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['cta_title'] ) ? $options['cta_title'] : '';
                $custom['excerpt']      = ! empty( $options['cta_description'] ) ? $options['cta_description'] : '';
                $custom['image']        = ! empty( $options['cta_image'] ) ? $options['cta_image'] : get_template_directory_uri() . '/assets/uploads/call-to-action.jpg';
                $custom['url']          = ! empty( $options['cta_btn_link'] ) ? $options['cta_btn_link'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['cta_content_page'] ) ? $options['cta_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['cta_content_post'] ) ? $options['cta_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $cta_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = musicsong_pro_trim_content( 25 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/call-to-action.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// cta section content details.
add_filter( 'musicsong_pro_filter_cta_section_details', 'musicsong_pro_get_cta_section_details' );


if ( ! function_exists( 'musicsong_pro_render_cta_section' ) ) :
  /**
   * Start cta section
   *
   * @return string cta content
   * @since Musicsong Pro 1.0.0
   *
   */
   function musicsong_pro_render_cta_section( $content_details = array() ) {
        $options = musicsong_pro_get_theme_options();
        $readmore = ! empty( $options['cta_btn_title'] ) ? $options['cta_btn_title'] : esc_html__( 'Read More', 'musicsong-pro' );

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>

            <div id="call-to-action" class="relative page-section" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                    <?php if ( ! empty( $content['title'] ) || ! empty( $options['cta_subtitle'] ) ) : ?>
                        <div class="section-header">
                            <?php if ( ! empty( $content['title'] ) ) : ?>
                                <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            <?php endif; 

                            if ( ! empty( $options['cta_subtitle'] ) ) : ?>
                                <p class="section-subtitle"><?php echo esc_html( $options['cta_subtitle'] ); ?></p>
                            <?php endif; ?>
                        </div><!-- .section-header -->
                    <?php endif;

                    if ( ! empty( $content['excerpt'] ) ) : ?>
                        <div class="section-content">
                            <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                        </div><!-- .entry-content -->
                    <?php endif;

                    if ( ! empty( $content['url'] ) ) : ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn">   <?php echo esc_html( $readmore ); ?>
                            </a>
                        </div><!-- .read-more -->
                    <?php endif; ?>
                </div><!-- .wrapper -->
            </div><!-- #call-to-action -->

        <?php endforeach; 
    }
endif;
