<?php
/**
 * Hero Content section
 *
 * This is the template for the content of hero content section
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */
if ( ! function_exists( 'musicsong_pro_add_hero_content_section' ) ) :
    /**
    * Add hero content section
    *
    *@since Musicsong Pro 1.0.0
    */
    function musicsong_pro_add_hero_content_section() {
    	$options = musicsong_pro_get_theme_options();
        // Check if hero content is enabled on frontpage
        $hero_content_enable = apply_filters( 'musicsong_pro_section_status', true, 'hero_content_section_enable' );

        if ( true !== $hero_content_enable ) {
            return false;
        }
        // Get hero content section details
        $section_details = array();
        $section_details = apply_filters( 'musicsong_pro_filter_hero_content_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render hero content section now.
        musicsong_pro_render_hero_content_section( $section_details );
    }
endif;

if ( ! function_exists( 'musicsong_pro_get_hero_content_section_details' ) ) :
    /**
    * hero content section details.
    *
    * @since Musicsong Pro 1.0.0
    * @param array $input hero content section details.
    */
    function musicsong_pro_get_hero_content_section_details( $input ) {
        $options = musicsong_pro_get_theme_options();

        // Content type.
        $hero_content_content_type  = $options['hero_content_content_type'];
        
        $content = array();
        switch ( $hero_content_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['hero_content_title'] ) ? $options['hero_content_title'] : '';
                $custom['excerpt']      = ! empty( $options['hero_content_description'] ) ? $options['hero_content_description'] : '';
                $custom['image']        = ! empty( $options['hero_content_image'] ) ? $options['hero_content_image'] : '';
                $custom['url']          = ! empty( $options['hero_content_btn_link'] ) ? $options['hero_content_btn_link'] : '';
                $custom['video']          = ! empty( $options['hero_content_video'] ) ? $options['hero_content_video'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['hero_content_content_page'] ) ? $options['hero_content_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['hero_content_content_post'] ) ? $options['hero_content_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $hero_content_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = musicsong_pro_trim_content( 25 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';
                    $page_post['video']     = ! empty( $options['hero_content_video'] ) ? $options['hero_content_video'] : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// hero content section content details.
add_filter( 'musicsong_pro_filter_hero_content_section_details', 'musicsong_pro_get_hero_content_section_details' );


if ( ! function_exists( 'musicsong_pro_render_hero_content_section' ) ) :
  /**
   * Start hero content section
   *
   * @return string hero content content
   * @since Musicsong Pro 1.0.0
   *
   */
   function musicsong_pro_render_hero_content_section( $content_details = array() ) {
        $options = musicsong_pro_get_theme_options();
        $readmore = ! empty( $options['hero_content_btn_title'] ) ? $options['hero_content_btn_title'] : esc_html__( 'Read More', 'musicsong-pro' );

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>

            <div id="featured-video" class="relative page-section">
                <div class="wrapper">
                    <?php if ( ! empty( $content['title'] ) || ! empty( $options['hero_content_subtitle'] ) ) : ?>
                        <div class="section-header">
                            <?php if ( ! empty( $content['title'] ) ) : ?>
                                <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            <?php endif; 

                            if ( ! empty( $options['hero_content_subtitle'] ) ) : ?>
                                <p class="section-subtitle"><?php echo esc_html( $options['hero_content_subtitle'] ); ?></p>
                            <?php endif; ?>
                        </div><!-- .section-header -->
                    <?php endif; 

                    if ( ! empty( $content['excerpt'] ) ) : ?>
                        <div class="section-content">
                            <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                        </div><!-- .section-content -->
                    <?php endif;

                    if ( ! empty( $content['url'] ) ) : ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-fill">   <?php echo esc_html( $readmore ); ?>
                            </a>
                        </div><!-- .read-more -->
                    <?php endif;

                    if ( ! empty( $content['video'] ) ) : 
                        $library_video =  attachment_url_to_postid( $content['video'] ); ?>
                        <div class="video-wrapper">
                            <?php if ( 0 !== $library_video ) :
                                the_widget( 'WP_Widget_Media_Video', $instance = array( 'attachment_id' => absint( $library_video ) ) ); 
                            else :
                                the_widget( 'WP_Widget_Media_Video', $instance = array( 'url' => esc_url( $content['video'] ) ) ); 
                            endif; ?>
                        </div><!-- .video-wrapper -->
                    <?php endif; ?>
                </div><!-- .wrapper -->
            </div><!-- #featured-video -->

        <?php endforeach;  
    }
endif;
