<?php
/**
 * Promotion section
 *
 * This is the template for the content of promotion section
 *
 * @package Theme Palace
 * @subpackage Musicsong Pro
 * @since Musicsong Pro 1.0.0
 */
if ( ! function_exists( 'musicsong_pro_add_promotion_section' ) ) :
    /**
    * Add promotion section
    *
    *@since Musicsong Pro 1.0.0
    */
    function musicsong_pro_add_promotion_section() {
    	$options = musicsong_pro_get_theme_options();
        // Check if promotion is enabled on frontpage
        $promotion_enable = apply_filters( 'musicsong_pro_section_status', true, 'promotion_section_enable' );

        if ( true !== $promotion_enable ) {
            return false;
        }
        // Get promotion section details
        $section_details = array();
        $section_details = apply_filters( 'musicsong_pro_filter_promotion_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render promotion section now.
        musicsong_pro_render_promotion_section( $section_details );
    }
endif;

if ( ! function_exists( 'musicsong_pro_get_promotion_section_details' ) ) :
    /**
    * promotion section details.
    *
    * @since Musicsong Pro 1.0.0
    * @param array $input promotion section details.
    */
    function musicsong_pro_get_promotion_section_details( $input ) {
        $options = musicsong_pro_get_theme_options();

        // Content type.
        $promotion_content_type  = $options['promotion_content_type'];
        
        $content = array();
        switch ( $promotion_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['promotion_title'] ) ? $options['promotion_title'] : '';
                $custom['excerpt']      = ! empty( $options['promotion_description'] ) ? $options['promotion_description'] : '';
                $custom['image']        = ! empty( $options['promotion_image'] ) ? $options['promotion_image'] : get_template_directory_uri() . '/assets/uploads/track.png';
                $custom['url']          = ! empty( $options['promotion_btn_link'] ) ? $options['promotion_btn_link'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['promotion_content_page'] ) ? $options['promotion_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['promotion_content_post'] ) ? $options['promotion_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $promotion_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = musicsong_pro_trim_content( 25 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// promotion section content details.
add_filter( 'musicsong_pro_filter_promotion_section_details', 'musicsong_pro_get_promotion_section_details' );


if ( ! function_exists( 'musicsong_pro_render_promotion_section' ) ) :
  /**
   * Start promotion section
   *
   * @return string promotion content
   * @since Musicsong Pro 1.0.0
   *
   */
   function musicsong_pro_render_promotion_section( $content_details = array() ) {
        $options = musicsong_pro_get_theme_options();
        $readmore = ! empty( $options['promotion_btn_title'] ) ? $options['promotion_btn_title'] : esc_html__( 'Read More', 'musicsong-pro' );


        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>

            <div id="promotion-section" class="relative page-section">
                <div class="wrapper">
                    <div class="promotion-section-wrapper">
                        <?php if ( ! empty( $content['image'] ) ) : ?>
                            <div class="featured-image">
                                <img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                            <img src="<?php echo esc_url( $content['image'] ); ?>" class="blur" alt="<?php echo esc_attr( $content['title'] ); ?>">
                            </div><!-- .featured-image -->
                        <?php endif; ?>

                        <div class="section-container">
                            <?php if ( ! empty( $content['title'] ) || ! empty( $options['promotion_subtitle'] ) ) : ?>
                                <div class="section-header">
                                    <?php if ( ! empty( $content['title'] ) ) : ?>
                                        <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                    <?php endif; 

                                    if ( ! empty( $options['promotion_subtitle'] ) ) : ?>
                                        <p class="section-subtitle"><?php echo esc_html( $options['promotion_subtitle'] ); ?></p>
                                    <?php endif; ?>
                                </div><!-- .section-header -->
                            <?php endif;

                            if ( ! empty( $content['excerpt'] ) ) : ?>
                                <div class="section-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->
                            <?php endif; ?>

                            <div class="read-more">
                                <?php if ( ! empty( $content['url'] ) ) : ?>
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-fill">   <?php echo esc_html( $readmore ); ?></a>
                                <?php endif; 

                                if ( ! empty( $options['promotion_alt_btn_title'] ) && ! empty( $options['promotion_alt_btn_link'] ) ) : ?>
                                    <a href="<?php echo esc_url( $options['promotion_alt_btn_link'] ); ?>" class="btn"><?php echo esc_html( $options['promotion_alt_btn_title'] ); ?></a>
                                <?php endif; ?>
                            </div><!-- .read-more -->
                        </div><!-- .section-container-->
                    </div><!-- .promotion-section-wrapper -->
                </div><!-- .wrapper -->
            </div><!-- #promotion-section -->

        <?php endforeach; 
    }
endif;
